@@ -34,11 +34,18 @@
 
 static int ifxmodem_init(void)
 {
+	ifx_voicecall_init();
+	ifx_radio_settings_init();
+	ifx_stk_init();
+
 	return 0;
 }
 
 static void ifxmodem_exit(void)
 {
+	ifx_stk_exit();
+	ifx_radio_settings_exit();
+	ifx_voicecall_exit();
 }
 
 OFONO_PLUGIN_DEFINE(ifxmodem, "Infineon modem driver", VERSION,
