@@ -41,6 +41,7 @@
 #include "isimodem.h"
 #include "isiutil.h"
 #include "ss.h"
+#include "debug.h"
 
 struct forw_data {
 	GIsiClient *client;
@@ -76,9 +77,10 @@ static int forw_type_to_isi_code(int type)
 	return ss_code;
 }
 
-static bool decode_gsm_forwarding_info(const void *restrict data, size_t len,
-					uint8_t *status, uint8_t *ton,
-					uint8_t *norply, char **number)
+static gboolean decode_gsm_forwarding_info(const void *restrict data,
+						size_t len,
+						uint8_t *status, uint8_t *ton,
+						uint8_t *norply, char **number)
 {
 	GIsiSubBlockIter iter;
 
@@ -102,7 +104,7 @@ static bool decode_gsm_forwarding_info(const void *restrict data, size_t len,
 				|| !g_isi_sb_iter_get_byte(&iter, &_numlen, 7)
 				|| !g_isi_sb_iter_get_alpha_tag(&iter, &_number,
 					_numlen * 2, 10))
-				return false;
+				return FALSE;
 
 			if (status)
 				*status = _status;
@@ -115,20 +117,21 @@ static bool decode_gsm_forwarding_info(const void *restrict data, size_t len,
 			else
 				g_free(_number);
 
-			return true;
+			return TRUE;
 		}
 		default:
-			DBG("Skipping sub-sub-block: 0x%04X (%zu bytes)",
-				g_isi_sb_iter_get_id(&iter),
+			DBG("Skipping sub-block: %s (%zd bytes)",
+				ss_subblock_name(g_isi_sb_iter_get_id(&iter)),
 				g_isi_sb_iter_get_len(&iter));
 			break;
 		}
 	}
-	return false;
+	return FALSE;
 }
 
-static bool registration_resp_cb(GIsiClient *client, const void *restrict data,
-				size_t len, uint16_t object, void *opaque)
+static gboolean registration_resp_cb(GIsiClient *client,
+					const void *restrict data, size_t len,
+					uint16_t object, void *opaque)
 {
 	GIsiSubBlockIter iter;
 	const unsigned char *msg = data;
@@ -141,7 +144,7 @@ static bool registration_resp_cb(GIsiClient *client, const void *restrict data,
 	}
 
 	if (len < 7 || msg[0] != SS_SERVICE_COMPLETED_RESP)
-		goto error;
+		return FALSE;
 
 	if (msg[1] != SS_REGISTRATION)
 		goto error;
@@ -177,8 +180,8 @@ static bool registration_resp_cb(GIsiClient *client, const void *restrict data,
 			break;
 		}
 		default:
-			DBG("Skipping sub-block: 0x%04X (%zu bytes)",
-				g_isi_sb_iter_get_id(&iter),
+			DBG("Skipping sub-block: %s (%zd bytes)",
+				ss_subblock_name(g_isi_sb_iter_get_id(&iter)),
 				g_isi_sb_iter_get_len(&iter));
 			break;
 		}
@@ -192,7 +195,7 @@ error:
 
 out:
 	g_free(cbd);
-	return true;
+	return TRUE;
 }
 
 static void isi_registration(struct ofono_call_forwarding *cf,
@@ -259,8 +262,9 @@ error:
 	g_free(cbd);
 }
 
-static bool erasure_resp_cb(GIsiClient *client, const void *restrict data,
-				size_t len, uint16_t object, void *opaque)
+static gboolean erasure_resp_cb(GIsiClient *client,
+				const void *restrict data, size_t len,
+				uint16_t object, void *opaque)
 {
 	GIsiSubBlockIter iter;
 	const unsigned char *msg = data;
@@ -308,8 +312,8 @@ static bool erasure_resp_cb(GIsiClient *client, const void *restrict data,
 			break;
 		}
 		default:
-			DBG("Skipping sub-block: 0x%04X (%zu bytes)",
-				g_isi_sb_iter_get_id(&iter),
+			DBG("Skipping sub-block: %s (%zd bytes)",
+				ss_subblock_name(g_isi_sb_iter_get_id(&iter)),
 				g_isi_sb_iter_get_len(&iter));
 			break;
 		}
@@ -323,7 +327,7 @@ error:
 
 out:
 	g_free(cbd);
-	return true;
+	return TRUE;
 }
 
 
@@ -364,8 +368,9 @@ error:
 	g_free(cbd);
 }
 
-static bool query_resp_cb(GIsiClient *client, const void *restrict data,
-				size_t len, uint16_t object, void *opaque)
+static gboolean query_resp_cb(GIsiClient *client,
+				const void *restrict data, size_t len,
+				uint16_t object, void *opaque)
 {
 	GIsiSubBlockIter iter;
 	const unsigned char *msg = data;
@@ -421,8 +426,8 @@ static bool query_resp_cb(GIsiClient *client, const void *restrict data,
 							&ton, &norply, &number))
 				goto error;
 
-			list.status = status & (SS_GSM_ACTIVE | SS_GSM_REGISTERED
-						| SS_GSM_PROVISIONED);
+			/* As in 27.007 section 7.11 */
+			list.status = status & SS_GSM_ACTIVE;
 			list.time = norply;
 			list.phone_number.type = ton | 128;
 			strncpy(list.phone_number.number, number,
@@ -433,8 +438,8 @@ static bool query_resp_cb(GIsiClient *client, const void *restrict data,
 			break;
 		}
 		default:
-			DBG("Skipping sub-block: 0x%04X (%zu bytes)",
-				g_isi_sb_iter_get_id(&iter),
+			DBG("Skipping sub-block: %s (%zd bytes)",
+				ss_subblock_name(g_isi_sb_iter_get_id(&iter)),
 				g_isi_sb_iter_get_len(&iter));
 			break;
 		}
@@ -452,7 +457,7 @@ error:
 
 out:
 	g_free(cbd);
-	return true;
+	return TRUE;
 
 }
 
@@ -504,20 +509,27 @@ static gboolean isi_call_forwarding_register(gpointer user)
 	return FALSE;
 }
 
-static void reachable_cb(GIsiClient *client, bool alive, uint16_t object,
+static void reachable_cb(GIsiClient *client, gboolean alive, uint16_t object,
 				void *opaque)
 {
 	struct ofono_call_forwarding *cf = opaque;
+	const char *debug = NULL;
 
-	if (alive == true) {
-		DBG("Resource 0x%02X, with version %03d.%03d reachable",
-			g_isi_client_resource(client),
-			g_isi_version_major(client),
-			g_isi_version_minor(client));
-		g_idle_add(isi_call_forwarding_register, cf);
+	if (!alive) {
+		DBG("Unable to bootstrap call forwarding driver");
 		return;
 	}
-	DBG("Unable to bootsrap call forwarding driver");
+
+	DBG("%s (v%03d.%03d) reachable",
+		pn_resource_name(g_isi_client_resource(client)),
+		g_isi_version_major(client),
+		g_isi_version_minor(client));
+
+	debug = getenv("OFONO_ISI_DEBUG");
+	if (debug && (strcmp(debug, "all") == 0 || strcmp(debug, "ss") == 0))
+		g_isi_client_set_debug(client, ss_debug, NULL);
+
+	g_idle_add(isi_call_forwarding_register, cf);
 }
 
 
@@ -537,6 +549,7 @@ static int isi_call_forwarding_probe(struct ofono_call_forwarding *cf,
 		return -ENOMEM;
 
 	ofono_call_forwarding_set_data(cf, data);
+
 	if (!g_isi_verify(data->client, reachable_cb, cf))
 		DBG("Unable to verify reachability");
 
@@ -547,10 +560,12 @@ static void isi_call_forwarding_remove(struct ofono_call_forwarding *cf)
 {
 	struct forw_data *data = ofono_call_forwarding_get_data(cf);
 
-	if (data) {
-		g_isi_client_destroy(data->client);
-		g_free(data);
-	}
+	if (!data)
+		return;
+
+	ofono_call_forwarding_set_data(cf, NULL);
+	g_isi_client_destroy(data->client);
+	g_free(data);
 }
 
 static struct ofono_call_forwarding_driver driver = {
